==> tine20-allinone_2019.12.5.tar.bz2: Crm/js/Crm-lang-cs-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Crm **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Czech (http://www.transifex.com/tine20/tine20/language/cs/)\nLanguage: cs\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Customer"
: "Zákazník"

, "State"
: "Status"

, "Role"
: "Role"

, "Source"
: "Zdroj"

, "Start"
: "Začátek"

, "Scheduled end"
: "Plánovaný konec"

, "End"
: "Konec"

, "Turnover"
: "Obrat"

, "Probability"
: "Pravděpodobnost"

, "Folder"
: "Složka"

, "Updated by"
: "Aktualizoval(a)"

, "Updated Fields:"
: "Aktualizované položky:"

, "'%s' changed from '%s' to '%s'."
: ""

, "Tags"
: "Štítky"

, "Lead %s has been changed"
: "Lead %s byl změněn"

, "Lead %s has been deleted"
: ""

, "Lead %s has been created"
: ""

, "Lead Data"
: "Data leadu"

, "Leadstate"
: "Stav leadu"

, "Leadtype"
: "Typ leadu"

, "Leadsource"
: "Zdroj leadu"

, "End Scheduled"
: "Plánovaný konec"

, "Contacts"
: "Kontakty"

, "Address"
: "Adresa"

, "Telephone"
: "Telefon"

, "Email"
: "Email"

, "Tasks"
: "Úkoly"

, "Due Date"
: "Termín dokončení"

, "Priority"
: "Priorita"

, "Products"
: "Produkty"

, "low"
: "nízká"

, "normal"
: "normální"

, "high"
: "vysoká"

, "urgent"
: "urgentní"

, "All leads I have read grants for"
: "Všechny leady, které jsem oprávněn číst"

, "Last modified by me"
: ""

, "All leads that I have last modified"
: ""

, "My leads"
: ""

, "All leads that I am responsible for"
: ""

, "Leads with overdue tasks"
: ""

, "All leads"
: "Všechny leady"

, "Default Lead List"
: ""

, "The default list for new leads"
: ""

, "Get Notification Emails"
: "Dostávat e-maily s upozorněním"

, "The level of actions you want to be notified about."
: "Úroveň činností o kterých chcete být informováni."

, "Send Notifications Emails for own actions"
: "Odesílat e-maily s upozorněním pro vlastní činnosti."

, "Get notifications emails for actions you did yourself"
: "Dostávat e-maily s upozorněním pro činnosti, které jste udělal(a)."

, "Send Notifications Emails to responsible"
: ""

, "Get notifications emails for action to responsible"
: ""

, "Send Notifications Emails to customer"
: ""

, "Get notifications emails for action to customer"
: ""

, "Send Notifications Emails to partner"
: ""

, "Get notifications emails for action to partner"
: ""

, "Default Favorite"
: "Výchozí oblíbené položky CRM"

, "The default favorite which is loaded on crm startup"
: "Výchozí oblíbené položky, které jsou načteny při spuštění CRM."

, "manage shared lead folders"
: "spravovat sdílené složky leadů"

, "Create new shared lead folders"
: "Vytvořit novou sdílenou složku leadů"

, "manage shared leads favorites"
: "spravovat sdílené oblíbené položky leadů"

, "Create or update shared leads favorites"
: "Vytvořit nebo aktualizovat sdílené oblíbené položky leadů"

, "Contact"
: "Kontakt"

, "CRM Role"
: "CRM role"

, "Lead, Leads"
: [
  "Lead"
 ,"Leady"
 ,"Leadů"
 ,"Leadů"

]
, "lead list, lead lists"
: [
  "seznam leadů"
 ,"seznamy leadů"
 ,"seznamů leadů"
 ,"seznamů leadů"

]
, "lead lists"
: "seznamy leadů"

, "Quick Search"
: ""

, "Lead name"
: "Jméno leadu"

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Creation Time"
: "Vytvořeno"

, "Created By"
: ""

, "Estimated end"
: "Odhadovaný konec"

, "Resubmission Date"
: ""

, "X Lead"
: ""

, "Archived"
: ""

, "Partner"
: "Partner"

, "Phone"
: "Telefon"

, "Mobile"
: "Mobil"

, "Fax"
: "Fax"

, "E-Mail"
: "E-mail"

, "Web"
: "Web"

, "Street"
: ""

, "Postalcode"
: ""

, "City"
: ""

, "Status"
: "Status"

, "Change type to Customer"
: "Změnit typ na Zákazník"

, "Responsible"
: "Odpovědná osoba"

, "Change type to Responsible"
: "Změnit typ na Odpovědná osoba"

, "Change type to Partner"
: "Změnit typ na Partner"

, "Change contact type"
: "Změnit typ kontaktu"

, "Search for Contacts to add ..."
: "Hledat kontakty pro přidání"

, "Name"
: "Jméno"

, "Data"
: "Data"

, "Cellphone"
: "Mobilní telefon"

, "Add new {0}"
: "Přidat nový {0}"

, "Unlink {0}"
: "Zrušit odkaz {0}"

, "Unlink selected {0}"
: "Zrušit odkaz(y) na vybraný/é {0}"

, "Edit {0}"
: "Editovat {0}"

, "Edit selected {0}"
: "Editovat vybraný/é {0}"

, "No Tasks to display"
: "Žádné úkoly ke zobrazení"

, "Summary"
: "Přehled"

, "Add a task..."
: "Přidat úkol..."

, "Percent"
: "Procent"

, "Organizer"
: ""

, "Please choose the Lead to add the contacts to"
: ""

, "Please select the attenders' role"
: ""

, "Select Lead"
: ""

, "Select Role"
: ""

, "Adding {0} contacts to lead"
: ""

, "Probable Turnover"
: "Předpokládaný obrat"

, "Import leads"
: ""

, "You do not have the run right for the Tasks application or it is not activated."
: "Nemáte oprávnění ke spuštění aplikace Úkoly nebo aplikace není povolena."

, "You do not have the run right for the Sales application or it is not activated."
: "Nemáte oprávnění ke spuštění aplikace Prodej nebo aplikace není povolena."

, "Enter lead name"
: ""

, "Expected turnover"
: "Očekávaný obrat"

, "Description"
: "Popis"

, "Enter description"
: "Zadejte popis"

, "New Lead"
: ""

, "Product"
: "Produkt"

, "Price"
: "Cena"

, "Quantity"
: "Množství"

, "Search for Products to add ..."
: "Hledat produkty pro přidání ..."

, "Edit new lead"
: ""

, "The following leads have just been imported into lead list %s"
: ""

, "%s new leads have been imported"
: ""

, "Lead CSV import"
: ""

, "Import list (###CURRENTDATE###)"
: ""

, "Leads imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: ""

, "Task"
: ""

, "Lead States Available"
: ""

, "Possible lead status, with their associated turnover probabilities. If a status is flagged, leads with this status are treated as closed."
: ""

, "open"
: "otevřený"

, "contacted"
: "kontaktovaný"

, "waiting for feedback"
: "čeká se na odezvu"

, "quote sent"
: "odeslána nabídka"

, "accepted"
: "přijatý"

, "lost"
: "ztracený"

, "Lead Sources Available"
: ""

, "Possible lead sources. If a source is flagged as archived, leads of this source are treated as closed."
: ""

, "Lead Types Available"
: ""

, "Possible lead types."
: ""

, "Reseller"
: "Dealer"

, "Enabled Features"
: ""

, "Enabled Features in Crm Application."
: ""

, "Lead Import"
: ""

, "Add new task on lead import"
: ""

, "Automatically creates a task for the responsible person if a new lead is imported."
: ""

, "Send notification email on lead import"
: ""

, "Sends an email to all responsible persons for the imported leads."
: ""

, "Lead duplicate check fields"
: ""

, "These fields are checked when a new lead is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: ""

, "Lead"
: "Lead"

, "lead list"
: "seznam leadů"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2020.03.4.tar.bz2: Crm/js/Crm-lang-cs-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Crm **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Czech (http://www.transifex.com/tine20/tine20/language/cs/)\nLanguage: cs\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "All leads"
: "Všechny leady"

, "Default Lead List"
: ""

, "The default list for new leads"
: ""

, "Get Notification E-mails"
: ""

, "The level of actions you want to be notified about."
: "Úroveň činností o kterých chcete být informováni."

, "Send Notifications e-mails for own actions"
: ""

, "Get notifications e-mails for actions you did yourself"
: ""

, "Send Notifications e-mails to responsible"
: ""

, "Get notifications e-mails for action to responsible"
: ""

, "Send Notifications e-mails to customer"
: ""

, "Get notifications e-mails for action to customer"
: ""

, "Send Notifications e-mails to partner"
: ""

, "Get notifications e-mails for action to partner"
: ""

, "Default Favorite"
: "Výchozí oblíbené položky CRM"

, "The default favorite which is loaded on crm startup"
: "Výchozí oblíbené položky, které jsou načteny při spuštění CRM."

, "New Lead"
: ""

, "Tags"
: "Štítky"

, "Lead name"
: "Jméno leadu"

, "Responsible"
: "Odpovědná osoba"

, "Partner"
: "Partner"

, "Customer"
: "Zákazník"

, "Leadstate"
: "Stav leadu"

, "Leadtype"
: "Typ leadu"

, "Leadsource"
: "Zdroj leadu"

, "Probability"
: "Pravděpodobnost"

, "Turnover"
: "Obrat"

, "Estimated end"
: "Odhadovaný konec"

, "Probable Turnover"
: "Předpokládaný obrat"

, "Resubmission Date"
: ""

, "Import leads"
: ""

, "Contact"
: "Kontakt"

, "CRM Role"
: "CRM role"

, "Tasks"
: "Úkoly"

, "No Tasks to display"
: "Žádné úkoly ke zobrazení"

, "Summary"
: "Přehled"

, "Add a task..."
: "Přidat úkol..."

, "Due Date"
: "Termín dokončení"

, "Priority"
: "Priorita"

, "Percent"
: "Procent"

, "Status"
: "Status"

, "Organizer"
: ""

, "Add new {0}"
: "Přidat nový {0}"

, "Unlink {0}"
: "Zrušit odkaz {0}"

, "Unlink selected {0}"
: "Zrušit odkaz(y) na vybraný/é {0}"

, "Edit {0}"
: "Editovat {0}"

, "Edit selected {0}"
: "Editovat vybraný/é {0}"

, "Please choose the Lead to add the contacts to"
: ""

, "Please select the attenders' role"
: ""

, "Lead, Leads"
: [
  "Lead"
 ,"Leady"
 ,"Leadů"
 ,"Leadů"

]
, "Select Lead"
: ""

, "Role"
: "Role"

, "Select Role"
: ""

, "Adding {0} contacts to lead"
: ""

, "Phone"
: "Telefon"

, "Mobile"
: "Mobil"

, "Fax"
: "Fax"

, "E-Mail"
: "E-mail"

, "Web"
: "Web"

, "Street"
: ""

, "Postalcode"
: ""

, "City"
: ""

, "Start"
: "Začátek"

, "Change type to Customer"
: "Změnit typ na Zákazník"

, "Change type to Responsible"
: "Změnit typ na Odpovědná osoba"

, "Change type to Partner"
: "Změnit typ na Partner"

, "Change contact type"
: "Změnit typ kontaktu"

, "Search for Contacts to add ..."
: "Hledat kontakty pro přidání"

, "Name"
: "Jméno"

, "Address"
: "Adresa"

, "Data"
: "Data"

, "Cellphone"
: "Mobilní telefon"

, "End"
: "Konec"

, "You do not have the run right for the Tasks application or it is not activated."
: "Nemáte oprávnění ke spuštění aplikace Úkoly nebo aplikace není povolena."

, "Products"
: "Produkty"

, "You do not have the run right for the Sales application or it is not activated."
: "Nemáte oprávnění ke spuštění aplikace Prodej nebo aplikace není povolena."

, "Enter lead name"
: ""

, "Expected turnover"
: "Očekávaný obrat"

, "Description"
: "Popis"

, "Enter description"
: "Zadejte popis"

, "lead list, lead lists"
: [
  "seznam leadů"
 ,"seznamy leadů"
 ,"seznamů leadů"
 ,"seznamů leadů"

]
, "lead lists"
: "seznamy leadů"

, "Quick Search"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Creation Time"
: "Vytvořeno"

, "Created By"
: ""

, "X Lead"
: ""

, "Archived"
: ""

, "Product"
: "Produkt"

, "Price"
: "Cena"

, "Quantity"
: "Množství"

, "Search for Products to add ..."
: "Hledat produkty pro přidání ..."

, "All leads I have read grants for"
: "Všechny leady, které jsem oprávněn číst"

, "Last modified by me"
: ""

, "All leads that I have last modified"
: ""

, "My leads"
: ""

, "All leads that I am responsible for"
: ""

, "Leads with overdue tasks"
: ""

, "Lead States Available"
: ""

, "Possible lead status, with their associated turnover probabilities. If a status is flagged, leads with this status are treated as closed."
: ""

, "open"
: "otevřený"

, "contacted"
: "kontaktovaný"

, "waiting for feedback"
: "čeká se na odezvu"

, "quote sent"
: "odeslána nabídka"

, "accepted"
: "přijatý"

, "lost"
: "ztracený"

, "Lead Sources Available"
: ""

, "Possible lead sources. If a source is flagged as archived, leads of this source are treated as closed."
: ""

, "Lead Types Available"
: ""

, "Possible lead types."
: ""

, "Reseller"
: "Dealer"

, "Enabled Features"
: ""

, "Enabled Features in CRM Application."
: ""

, "Lead Import"
: ""

, "Add new task on lead import"
: ""

, "Automatically creates a task for the responsible person if a new lead is imported."
: ""

, "Send notification e-mail on lead import"
: ""

, "Sends an e-mail to all responsible persons for the imported leads."
: ""

, "Lead duplicate check fields"
: ""

, "These fields are checked when a new lead is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: ""

, "State"
: "Status"

, "Source"
: "Zdroj"

, "Scheduled end"
: "Plánovaný konec"

, "Folder"
: "Složka"

, "Updated by"
: "Aktualizoval(a)"

, "Updated Fields:"
: "Aktualizované položky:"

, "'%s' changed from '%s' to '%s'."
: ""

, "Lead %s has been changed"
: "Lead %s byl změněn"

, "Lead %s has been deleted"
: ""

, "Lead %s has been created"
: ""

, "Task"
: ""

, "Lead Data"
: "Data leadu"

, "End Scheduled"
: "Plánovaný konec"

, "Contacts"
: "Kontakty"

, "Telephone"
: "Telefon"

, "Email"
: "Email"

, "low"
: "nízká"

, "normal"
: "normální"

, "high"
: "vysoká"

, "urgent"
: "urgentní"

, "Lead CSV import"
: ""

, "Import list (###CURRENTDATE###)"
: ""

, "Leads imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: ""

, "Edit new lead"
: ""

, "The following leads have just been imported into lead list %s"
: ""

, "%s new leads have been imported"
: ""

, "manage shared lead folders"
: "spravovat sdílené složky leadů"

, "Create new shared lead folders"
: "Vytvořit novou sdílenou složku leadů"

, "manage shared leads favorites"
: "spravovat sdílené oblíbené položky leadů"

, "Create or update shared leads favorites"
: "Vytvořit nebo aktualizovat sdílené oblíbené položky leadů"




, "Lead"
: "Lead"

, "lead list"
: "seznam leadů"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
